@@ -6,6 +6,7 @@ import python_build
 import hitchpython
 import shutil
 import sys
+import os
 
 
 class HitchPythonBuildError(Exception):
@@ -23,15 +24,13 @@ class PythonPackage(HitchPackage):
         #'2.5', '2.5.1', '2.5.2', '2.5.3', '2.5.4', '2.5.5', '2.5.6',
         '2.6.6', '2.6.7', '2.6.8', '2.6.9',
         '2.7', '2.7.1', '2.7.2', '2.7.3', '2.7.4',
-        '2.7.5', '2.7.6', '2.7.7', '2.7.8', '2.7.9', '2.7.10', '2.7-dev',
+        '2.7.5', '2.7.6', '2.7.7', '2.7.8', '2.7.9', '2.7.10', '2.7.11',
         #'3.0.1', '3.1-dev', '3.1', '3.1.1', '3.1.2', '3.1.3', '3.1.4', '3.1.5',
-        '3.2', '3.2.1', '3.2.2', '3.2.3', '3.2.4', '3.2.5', '3.2.6', #'3.2-dev',
+        '3.2', '3.2.1', '3.2.2', '3.2.3', '3.2.4', '3.2.5', '3.2.6',
         '3.3.0',
-        #'3.3-dev',
         '3.3.1', '3.3.2', '3.3.3', '3.3.4', '3.3.5', '3.3.6',
         '3.4.0',
-        #'3.4-dev',
-        '3.4.1', '3.4.2', '3.4.3', '3.5.0', '3.5-dev',
+        '3.4.1', '3.4.2', '3.4.3', '3.5.0', '3.5.1',
     ]
 
     def __init__(self, python_version="2.7.10", directory=None, bin_directory=None):
@@ -55,21 +54,46 @@ class PythonPackage(HitchPackage):
 
     def build(self):
         """Download and compile the specified version of python and create virtualenv from it."""
-        try:
-            self.base_python_bin_directory = path.join(self.base_python_main_directory, "bin")
-            if not path.exists(self.base_python_main_directory):
-                python_build.build.python_build(self.python_version, self.base_python_main_directory)
-                check_call([path.join(self.base_python_bin_directory, "easy_install"), "--upgrade", "setuptools"])
-                check_call([path.join(self.base_python_bin_directory, "easy_install"), "--upgrade", "pip"])
-                check_call([path.join(self.base_python_bin_directory, "pip"), "install", "virtualenv", "-U"])
+        env_vars = os.environ.copy()
+        if "PIP_REQUIRE_VIRTUALENV" in env_vars:
+            env_vars.pop("PIP_REQUIRE_VIRTUALENV")
 
-                # If an earlier run with a previous .hitchpkg python created the virtualenv, blow it away
+        try:
+            self.base_python_bin_directory = path.join(
+                self.base_python_main_directory, "bin"
+            )
+            if not path.exists(self.base_python_main_directory):
+                try:
+                    checks.internet_detected_after(5)
+                except checks.HitchEnvironmentException:
+                    raise HitchPythonBuildError(
+                        "Internet access not detected -- cannot install python environment."
+                    )
+                python_build.build.python_build(
+                    self.python_version, self.base_python_main_directory
+                )
+                easy_install = path.join(
+                    self.base_python_bin_directory, "easy_install"
+                )
+                check_call([easy_install, "--upgrade", "setuptools"])
+                check_call([easy_install, "--upgrade", "pip"])
+                check_call(
+                    [
+                        path.join(self.base_python_bin_directory, "pip"),
+                        "install", "virtualenv", "-U"
+                    ],
+                    env=env_vars
+                )
+
+                # Blow away virtualenv if it exists
                 if path.exists(self.directory):
                     shutil.rmtree(self.directory)
 
             # If virtualenv doesn't exist yet, create it.
             if not path.exists(self.directory):
-                check_call([path.join(self.base_python_bin_directory, "virtualenv"), self.directory])
+                check_call(
+                    [path.join(self.base_python_bin_directory, "virtualenv"), self.directory]
+                )
         except (CalledProcessError, KeyboardInterrupt):
             if path.exists(self.base_python_main_directory):
                 shutil.rmtree(self.base_python_main_directory)
@@ -79,8 +103,8 @@ class PythonPackage(HitchPackage):
                 "Error occurred when trying to build python.\n"
                 "If the cause is not obvious, please raise an issue at "
                 "https://github.com/hitchtest/hitchpython/issues detailing:\n"
-                "Your OS, OS version and package manager. Please also copy and paste everything "
-                "above this exception."
+                "Your OS, OS version and package manager. "
+                "Please also copy and paste everything above this exception."
             ))
 
         self.bin_directory = path.join(self.directory, "bin")
